@@ -25,7 +25,7 @@ use constant RECURSION_LIMIT   => $ENV{JSON_VALIDATOR_RECURSION_LIMIT} || 100;
 use constant SPECIFICATION_URL => 'http://json-schema.org/draft-04/schema#';
 
 our $DEFINITIONS = 'definitions';
-our $VERSION = '3.09';
+our $VERSION = '3.10';
 our $YAML_LOADER = eval q[use YAML::XS 0.67; YAML::XS->can('Load')];  # internal
 our @EXPORT_OK   = qw(joi validate_json);
 
@@ -70,8 +70,6 @@ sub bundle {
   local $DEFINITIONS = $args->{ref_key} || $DEFINITIONS;
   Mojo::Util::deprecated('bundle({ref_key => "..."}) will be removed.')
     if $args->{ref_key};
-  Mojo::Util::deprecated('bundle({replace => 1}) will be removed.')
-    if $args->{replace};
 
   if ($args->{replace}) {
     $cloner = sub {
@@ -122,6 +120,7 @@ sub bundle {
     }
   }
 
+  delete $bundle->{$DEFINITIONS} unless keys %{$bundle->{$DEFINITIONS}};
   return $bundle;
 }
 
